@@ -27,7 +27,7 @@ class NotificationStack(Stack):
     '''
     This Stack ...
     '''
-    def __init__(self, scope: Construct, construct_id: str, pinpoint_app_name: str, apns_bundle_id: str, apns_certificate_path: str, apns_private_key_path: str,  **kwargs) -> None:
+    def __init__(self, scope: Construct, construct_id: str, pinpoint_app_name: str, apns_certificate_path: str, apns_private_key_path: str,  **kwargs) -> None:
         super().__init__(scope, construct_id, **kwargs)
 
         pinpoint_app = pinpoint.CfnApp(self, pinpoint_app_name, name=pinpoint_app_name)  
@@ -37,7 +37,7 @@ class NotificationStack(Stack):
             application_id=pinpoint_app.ref,
 
             # the properties below are optional
-            bundle_id=apns_bundle_id,
+            # bundle_id=apns_bundle_id,
             certificate=open(apns_certificate_path).read(),
             default_authentication_method="certificate", 
             enabled=False,
